==> totoui-0.3.0.tgz: package/lib/menu.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var _avgGridJsx = require('./avgGrid.js');

var _avgGridJsx2 = _interopRequireDefault(_avgGridJsx);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var Menu = (function (_React$Component) {
    _inherits(Menu, _React$Component);

    function Menu(props) {
        _classCallCheck(this, Menu);

        _get(Object.getPrototypeOf(Menu.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        this.state = {
            data: this.props.data,
            expanded: !this.isDropdown()
        };
        this.handleClick = this.handleClick.bind(this);
        this.handleParentClick = this.handleParentClick.bind(this);
        this.closeAll = this.closeAll.bind(this);
        this.handleToggle = this.handleToggle.bind(this);
        this.isDropdown = this.isDropdown.bind(this);
        this.renderMenuToggle = this.renderMenuToggle.bind(this);
        this.renderNavs = this.renderNavs.bind(this);
    }

    _createClass(Menu, [{
        key: 'handleClick',
        value: function handleClick(nav, index, closeAll, e) {
            if (nav && nav.subMenu) {
                this.handleParentClick(nav, index, closeAll, e);
            }

            this.props.onSelect.call(this, nav, index, e);
        }

        /**
         * handle nav with subMenu click
         * @param {object} nav - clicked nav
         * @param {number} index - clicked nav index
         * @param {bool} closeAll - close all submenu
         * @param {object} e
         */
    }, {
        key: 'handleParentClick',
        value: function handleParentClick(nav, index, closeAll, e) {
            e && e.preventDefault();

            var data = this.state.data.map(function (item, i) {
                item.subActive = closeAll ? false : index === i ? !item.subActive : false;
                return item;
            });

            this.setState({
                data: data
            });
        }
    }, {
        key: 'closeAll',
        value: function closeAll() {
            this.handleParentClick(null, null, true, undefined);
        }

        // handle toggle button click for dropdown/slide theme
    }, {
        key: 'handleToggle',
        value: function handleToggle(e) {
            e && e.preventDefault();
            this.setState({
                expanded: !this.state.expanded
            }, (function () {
                !this.state.expanded && this.closeAll();
            }).bind(this));
        }
    }, {
        key: 'isDropdown',
        value: function isDropdown() {
            return ['dropdown1', 'dropdown2', 'slide1'].indexOf(this.props.theme) > -1;
        }
    }, {
        key: 'renderMenuToggle',
        value: function renderMenuToggle() {
            var title = this.props.toggleTitle ? _react2['default'].createElement(
                'span',
                { className: this.prefixClass('toggle-title') },
                this.props.toggleTitle
            ) : null;
            var icon = this.props.toggleCustomIcon ? _react2['default'].createElement('img', { src: this.props.toggleCustomIcon, alt: "Menu Toggle" }) : _react2['default'].createElement(_iconJsx2['default'], {
                className: this.prefixClass('toggle-icon'),
                icon: this.props.toggleIcon || 'bars' });

            return _react2['default'].createElement(
                'a',
                {
                    href: "#",
                    onTouchStart: this.handleToggle,
                    className: (0, _classnames2['default'])(this.prefixClass('toggle'), this.state.expanded ? this.setClassNamespace('active') : null) },
                title,
                icon
            );
        }
    }, {
        key: 'renderNavs',
        value: function renderNavs() {
            var _this = this;
            var openClassName = this.setClassNamespace('open');
            var inClassName = this.setClassNamespace('in');

            return this.state.data.map(function (nav, i) {
                return _react2['default'].createElement(
                    'li',
                    {
                        key: i,
                        className: (0, _classnames2['default'])(nav.subMenu ? _this.setClassNamespace('parent') : null, nav.subActive ? openClassName : null) },
                    _react2['default'].createElement(
                        'a',
                        {
                            onTouchStart: _this.handleClick.bind(_this, nav, i, false),
                            href: nav.link },
                        nav.title
                    ),
                    nav.subMenu ? _react2['default'].createElement(
                        _avgGridJsx2['default'],
                        {
                            sm: nav.subCols || 1,
                            className: (0, _classnames2['default'])(_this.prefixClass('sub'), _this.setClassNamespace('collapse'), nav.subActive ? inClassName : null) },
                        nav.subMenu.map(function (subNav, index) {
                            return _react2['default'].createElement(
                                'li',
                                { key: index },
                                _react2['default'].createElement(
                                    'a',
                                    {
                                        onTouchStart: _this.handleClick.bind(_this, subNav, [i, index], false),
                                        target: subNav.target,
                                        href: subNav.link },
                                    subNav.title
                                )
                            );
                        })
                    ) : null
                );
            });
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();
            var props = (0, _objectOmit2['default'])(this.props, 'data');
            var hideTopLevel = !this.state.expanded ? this.setClassNamespace('collapse') : null;

            return _react2['default'].createElement(
                'nav',
                _extends({}, props, {
                    'data-am-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(this.props.className, classSet) }),
                this.renderMenuToggle(),
                _react2['default'].createElement(
                    _avgGridJsx2['default'],
                    {
                        sm: this.props.cols,
                        className: (0, _classnames2['default'])(this.prefixClass('nav'), hideTopLevel) },
                    this.renderNavs()
                )
            );
        }
    }]);

    return Menu;
})(_react2['default'].Component);

Menu.displayName = "Menu";

Menu.propTypes = {
    classPrefix: _react2['default'].PropTypes.string,
    theme: _react2['default'].PropTypes.oneOf(['default', 'dropdown1', 'dropdown2', 'slide1', 'stack']),
    data: _react2['default'].PropTypes.array,
    onSelect: _react2['default'].PropTypes.func,
    toggleTitle: _react2['default'].PropTypes.string,
    toggleCustomIcon: _react2['default'].PropTypes.string,
    toggleIcon: _react2['default'].PropTypes.string,
    cols: _react2['default'].PropTypes.number
};

Menu.defaultProps = {
    classPrefix: 'menu',
    theme: 'default',
    data: [],
    onSelect: function onSelect() {}
};

module.exports = Menu;

==> totoui-0.5.1.tgz: package/lib/menu.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var _avgGridJsx = require('./avgGrid.js');

var _avgGridJsx2 = _interopRequireDefault(_avgGridJsx);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var Menu = (function (_React$Component) {
    _inherits(Menu, _React$Component);

    function Menu(props) {
        _classCallCheck(this, Menu);

        _get(Object.getPrototypeOf(Menu.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        this.state = {
            data: this.props.data,
            expanded: !this.isDropdown()
        };
        this.handleClick = this.handleClick.bind(this);
        this.handleParentClick = this.handleParentClick.bind(this);
        this.closeAll = this.closeAll.bind(this);
        this.handleToggle = this.handleToggle.bind(this);
        this.isDropdown = this.isDropdown.bind(this);
        this.renderMenuToggle = this.renderMenuToggle.bind(this);
        this.renderNavs = this.renderNavs.bind(this);
    }

    _createClass(Menu, [{
        key: 'handleClick',
        value: function handleClick(nav, index, closeAll, e) {
            if (nav && nav.subMenu) {
                this.handleParentClick(nav, index, closeAll, e);
            }

            this.props.onSelect.call(this, nav, index, e);
        }

        /**
         * handle nav with subMenu click
         * @param {object} nav - clicked nav
         * @param {number} index - clicked nav index
         * @param {bool} closeAll - close all submenu
         * @param {object} e
         */
    }, {
        key: 'handleParentClick',
        value: function handleParentClick(nav, index, closeAll, e) {
            e && e.preventDefault();

            var data = this.state.data.map(function (item, i) {
                item.subActive = closeAll ? false : index === i ? !item.subActive : false;
                return item;
            });

            this.setState({
                data: data
            });
        }
    }, {
        key: 'closeAll',
        value: function closeAll() {
            this.handleParentClick(null, null, true, undefined);
        }

        // handle toggle button click for dropdown/slide theme
    }, {
        key: 'handleToggle',
        value: function handleToggle(e) {
            e && e.preventDefault();
            this.setState({
                expanded: !this.state.expanded
            }, (function () {
                !this.state.expanded && this.closeAll();
            }).bind(this));
        }
    }, {
        key: 'isDropdown',
        value: function isDropdown() {
            return ['dropdown1', 'dropdown2', 'slide1'].indexOf(this.props.theme) > -1;
        }
    }, {
        key: 'renderMenuToggle',
        value: function renderMenuToggle() {
            var title = this.props.toggleTitle ? _react2['default'].createElement(
                'span',
                { className: this.prefixClass('toggle-title') },
                this.props.toggleTitle
            ) : null;
            var icon = this.props.toggleCustomIcon ? _react2['default'].createElement('img', { src: this.props.toggleCustomIcon, alt: 'Menu Toggle' }) : _react2['default'].createElement(_iconJsx2['default'], {
                className: this.prefixClass('toggle-icon'),
                icon: this.props.toggleIcon || 'bars' });

            return _react2['default'].createElement(
                'a',
                {
                    href: '#',
                    onTouchTap: this.handleToggle,
                    className: (0, _classnames2['default'])(this.prefixClass('toggle'), this.state.expanded ? this.setClassNamespace('active') : null) },
                title,
                icon
            );
        }
    }, {
        key: 'renderNavs',
        value: function renderNavs() {
            var _this = this;
            var openClassName = this.setClassNamespace('open');
            var inClassName = this.setClassNamespace('in');

            return this.state.data.map(function (nav, i) {
                return _react2['default'].createElement(
                    'li',
                    {
                        key: i,
                        className: (0, _classnames2['default'])(nav.subMenu ? _this.setClassNamespace('parent') : null, nav.subActive ? openClassName : null) },
                    _react2['default'].createElement(
                        'a',
                        {
                            onTouchTap: _this.handleClick.bind(_this, nav, i, false),
                            href: nav.link },
                        nav.title
                    ),
                    nav.subMenu ? _react2['default'].createElement(
                        _avgGridJsx2['default'],
                        {
                            sm: nav.subCols || 1,
                            className: (0, _classnames2['default'])(_this.prefixClass('sub'), _this.setClassNamespace('collapse'), nav.subActive ? inClassName : null) },
                        nav.subMenu.map(function (subNav, index) {
                            return _react2['default'].createElement(
                                'li',
                                { key: index },
                                _react2['default'].createElement(
                                    'a',
                                    {
                                        onTouchTap: _this.handleClick.bind(_this, subNav, [i, index], false),
                                        target: subNav.target,
                                        href: subNav.link },
                                    subNav.title
                                )
                            );
                        })
                    ) : null
                );
            });
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();
            var props = (0, _objectOmit2['default'])(this.props, 'data');
            var hideTopLevel = !this.state.expanded ? this.setClassNamespace('collapse') : null;

            return _react2['default'].createElement(
                'nav',
                _extends({}, props, {
                    'data-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(this.props.className, classSet) }),
                this.renderMenuToggle(),
                _react2['default'].createElement(
                    _avgGridJsx2['default'],
                    {
                        sm: this.props.cols,
                        className: (0, _classnames2['default'])(this.prefixClass('nav'), hideTopLevel) },
                    this.renderNavs()
                )
            );
        }
    }]);

    return Menu;
})(_react2['default'].Component);

Menu.displayName = "Menu";

Menu.propTypes = {
    classPrefix: _react2['default'].PropTypes.string,
    theme: _react2['default'].PropTypes.oneOf(['default', 'dropdown1', 'dropdown2', 'slide1', 'stack']),
    data: _react2['default'].PropTypes.array,
    onSelect: _react2['default'].PropTypes.func,
    toggleTitle: _react2['default'].PropTypes.string,
    toggleCustomIcon: _react2['default'].PropTypes.string,
    toggleIcon: _react2['default'].PropTypes.string,
    cols: _react2['default'].PropTypes.number
};

Menu.defaultProps = {
    classPrefix: 'menu',
    theme: 'default',
    data: [],
    onSelect: function onSelect() {}
};

module.exports = Menu;
